#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
from __future__ import annotations

from typing import TYPE_CHECKING, Any, Sequence

from airflow.sensors.base import BaseSensorOperator

if TYPE_CHECKING:
    from airflow.utils.context import Context


class WebHdfsSensor(BaseSensorOperator):
    """Waits for a file or folder to land in HDFS"""

    template_fields: Sequence[str] = ("filepath",)

    def __init__(self, *, filepath: str, webhdfs_conn_id: str = "webhdfs_default", **kwargs: Any) -> None:
        super().__init__(**kwargs)
        self.filepath = filepath
        self.webhdfs_conn_id = webhdfs_conn_id

    def poke(self, context: Context) -> bool:
        from airflow.providers.apache.hdfs.hooks.webhdfs import WebHDFSHook

        hook = WebHDFSHook(self.webhdfs_conn_id)
        self.log.info("Poking for file %s", self.filepath)
        return hook.check_for_path(hdfs_path=self.filepath)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# NOTE! THIS FILE IS AUTOMATICALLY GENERATED AND WILL BE
# OVERWRITTEN WHEN PREPARING PACKAGES.
#
# IF YOU WANT TO MODIFY IT, YOU SHOULD MODIFY THE TEMPLATE
# `get_provider_info_TEMPLATE.py.jinja2` IN the `provider_packages` DIRECTORY


def get_provider_info():
    return {
        "package-name": "apache-airflow-providers-apache-hdfs",
        "name": "Apache HDFS",
        "description": "`Hadoop Distributed File System (HDFS) <https://hadoop.apache.org/docs/r1.2.1/hdfs_design.html>`__\nand `WebHDFS <https://hadoop.apache.org/docs/current/hadoop-project-dist/hadoop-hdfs/WebHDFS.html>`__.\n",
        "versions": [
            "3.2.0",
            "3.1.0",
            "3.0.1",
            "3.0.0",
            "2.2.3",
            "2.2.2",
            "2.2.1",
            "2.2.0",
            "2.1.1",
            "2.1.0",
            "2.0.0",
            "1.0.1",
            "1.0.0",
        ],
        "dependencies": ["apache-airflow>=2.3.0", "snakebite-py3", "hdfs[avro,dataframe,kerberos]>=2.0.4"],
        "integrations": [
            {
                "integration-name": "Hadoop Distributed File System (HDFS)",
                "external-doc-url": "https://hadoop.apache.org/docs/r1.2.1/hdfs_design.html",
                "how-to-guide": ["/docs/apache-airflow-providers-apache-hdfs/operators/hdfs.rst"],
                "logo": "/integration-logos/apache/hadoop.png",
                "tags": ["apache"],
            },
            {
                "integration-name": "WebHDFS",
                "external-doc-url": "https://hadoop.apache.org/docs/current/hadoop-project-dist/hadoop-hdfs/WebHDFS.html",
                "how-to-guide": ["/docs/apache-airflow-providers-apache-hdfs/operators/webhdfs.rst"],
                "logo": "/integration-logos/apache/hadoop.png",
                "tags": ["apache"],
            },
        ],
        "sensors": [
            {
                "integration-name": "Hadoop Distributed File System (HDFS)",
                "python-modules": ["airflow.providers.apache.hdfs.sensors.hdfs"],
            },
            {
                "integration-name": "WebHDFS",
                "python-modules": ["airflow.providers.apache.hdfs.sensors.web_hdfs"],
            },
        ],
        "hooks": [
            {
                "integration-name": "Hadoop Distributed File System (HDFS)",
                "python-modules": ["airflow.providers.apache.hdfs.hooks.hdfs"],
            },
            {
                "integration-name": "WebHDFS",
                "python-modules": ["airflow.providers.apache.hdfs.hooks.webhdfs"],
            },
        ],
        "connection-types": [
            {
                "hook-class-name": "airflow.providers.apache.hdfs.hooks.hdfs.HDFSHook",
                "connection-type": "hdfs",
            }
        ],
    }
